==> apache-cxf-3.4.5-src.tar.gz: apache-cxf-3.4.5-src/rt/transports/http/src/main/java/org/apache/cxf/transport/http/HTTPSession.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.transport.http;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpSession;

import org.apache.cxf.transport.Session;

/**
 * A session implementation bound to HTTP.
 */
public class HTTPSession implements Session {
    private HttpServletRequest request;

    private HttpSession session;

    public HTTPSession(HttpServletRequest request) {
        this.request = request;
    }

    public Object get(Object key) {
        return getSession().getAttribute(key.toString());
    }

    public void put(Object key, Object value) {
        getSession().setAttribute(key.toString(), value);
    }

    public HttpSession getSession() {
        if (session == null) {
            session = request.getSession();
        }

        return session;
    }
}

==> apache-cxf-4.0.7-src.tar.gz: apache-cxf-4.0.7-src/rt/transports/http/src/main/java/org/apache/cxf/transport/http/HTTPSession.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.transport.http;

import jakarta.servlet.http.HttpServletRequest;
import jakarta.servlet.http.HttpSession;
import org.apache.cxf.transport.Session;

/**
 * A session implementation bound to HTTP.
 */
public class HTTPSession implements Session {
    private HttpServletRequest request;

    private HttpSession session;

    public HTTPSession(HttpServletRequest request) {
        this.request = request;
    }

    public Object get(Object key) {
        return getSession().getAttribute(key.toString());
    }

    public void put(Object key, Object value) {
        getSession().setAttribute(key.toString(), value);
    }

    public HttpSession getSession() {
        if (session == null) {
            session = request.getSession();
        }

        return session;
    }
}
